@@ -1,6 +1,10 @@
 from datetime import date
 
-from .utils import streams
+from .utils import (
+    len_color,
+    streams
+)
+from .shortcuts import progressbar
 
 from .widgets import (
     Timer,
@@ -39,6 +43,8 @@ from .__about__ import (
 
 __date__ = str(date.today())
 __all__ = [
+    'progressbar',
+    'len_color',
     'streams',
     'Timer',
     'ETA',
